<?php
/**
 * WEN Biz functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Wen_Biz
 */

if ( ! function_exists( 'wen_biz_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function wen_biz_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on WEN Biz, use a find and replace
		 * to change 'wen-biz' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'wen-biz', get_parent_theme_file_path( '/languages' ) );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * This theme styles the visual editor to resemble the theme style,
		 * specifically font, colors, and column width.
		 *
		 * Google fonts url addition
		 *
		 * Font Awesome addition
		 */
		add_editor_style( array(
			'css/editor-style.css',
			wen_biz_fonts_url(),
			trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'css/font-awesome/css/font-awesome.css' )
		);

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// Used in Blog post
		set_post_thumbnail_size( 960, 640, true ); // Ratio 3:2

		// Used in featured slider
		add_image_size( 'wen-biz-slider', 1920, 822, true ); //21:9

		// Used in featured content
		add_image_size( 'wen-biz-featured-content', 507, 338, true ); //3:2

		// Used in hero section
		add_image_size( 'wen-biz-hero', 604, 604, true ); //1:1

		// Used in promotional content
		add_image_size( 'wen-biz-promotional-content', 604, 755, true ); //4:5

		// Used in promotional headline
		add_image_size( 'wen-biz-promotional-headline', 604, 755, true ); //4:5

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1'          => esc_html__( 'Primary', 'wen-biz' ),
			'social-footer'   => esc_html__( 'Footer Social Menu', 'wen-biz' )
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );

		/**
		 * Add support for essential widget image.
		 *
		 */
		add_theme_support( 'ew-newsletter-image' );

		// Add support for Block Styles.
		add_theme_support( 'wp-block-styles' );

		// Add support for full and wide align images.
		add_theme_support( 'align-wide' );

		// Add support for editor styles.
		add_theme_support( 'editor-styles' );

		// Add support for responsive embeds.
		add_theme_support( 'responsive-embeds' );

		// Add custom editor font sizes.
		add_theme_support(
			'editor-font-sizes',
			array(
				array(
					'name'      => esc_html__( 'Extra small', 'wen-biz' ),
					'shortName' => esc_html__( 'XS', 'wen-biz' ),
					'size'      => 13,
					'slug'      => 'extra-small',
				),
				array(
					'name'      => esc_html__( 'Small', 'wen-biz' ),
					'shortName' => esc_html__( 'S', 'wen-biz' ),
					'size'      => 16,
					'slug'      => 'small',
				),
				array(
					'name'      => esc_html__( 'Normal', 'wen-biz' ),
					'shortName' => esc_html__( 'M', 'wen-biz' ),
					'size'      => 20,
					'slug'      => 'normal',
				),
				array(
					'name'      => esc_html__( 'Large', 'wen-biz' ),
					'shortName' => esc_html__( 'L', 'wen-biz' ),
					'size'      => 42,
					'slug'      => 'large',
				),
				array(
					'name'      => esc_html__( 'Extra large', 'wen-biz' ),
					'shortName' => esc_html__( 'XL', 'wen-biz' ),
					'size'      => 58,
					'slug'      => 'extra-large',
				),
				array(
					'name'      => esc_html__( 'Huge', 'wen-biz' ),
					'shortName' => esc_html__( 'XL', 'wen-biz' ),
					'size'      => 70,
					'slug'      => 'huge',
				),
			)
		);

		// Add support for custom color scheme.
		add_theme_support( 'editor-color-palette', array(
			array(
				'name'  => esc_html__( 'White', 'wen-biz' ),
				'slug'  => 'white',
				'color' => '#ffffff',
			),
			array(
				'name'  => esc_html__( 'Black', 'wen-biz' ),
				'slug'  => 'black',
				'color' => '#000000',
			),
			array(
				'name'  => esc_html__( 'Medium Black', 'wen-biz' ),
				'slug'  => 'medium-black',
				'color' => '#222222',
			),
			array(
				'name'  => esc_html__( 'Gray', 'wen-biz' ),
				'slug'  => 'gray',
				'color' => '#999999',
			),
			array(
				'name'  => esc_html__( 'Light Gray', 'wen-biz' ),
				'slug'  => 'light-gray',
				'color' => '#f8f8f8',
			),
			array(
				'name'  => esc_html__( 'Orange', 'wen-biz' ),
				'slug'  => 'orange',
				'color' => '#f95042',
			),
			array(
				'name'  => esc_html__( 'Pink', 'wen-biz' ),
				'slug'  => 'pink',
				'color' => '#e03ae0',
			),
		) );

		/**
		 * Adds support for Catch Breadcrumb.
		 */
		add_theme_support( 'catch-breadcrumb', array(
			'content_selector'   => '.custom-header .entry-header',
			'breadcrumb_dynamic' => 'after',
		) );
	}
endif;
add_action( 'after_setup_theme', 'wen_biz_setup' );

/**
 * Count the number of footer sidebars to enable dynamic classes for the footer
 *
 */
function wen_biz_footer_sidebar_class() {
	$count = 0;

	if ( is_active_sidebar( 'sidebar-2' ) ) {
		$count++;
	}

	if ( is_active_sidebar( 'sidebar-3' ) ) {
		$count++;
	}

	if ( is_active_sidebar( 'sidebar-4' ) ) {
		$count++;
	}

	$class = '';

	switch ( $count ) {
		case '1':
			$class = 'one';
			break;
		case '2':
			$class = 'two';
			break;
		case '3':
			$class = 'three';
			break;
	}

	if ( $class ) {
		echo 'class="widget-area footer-widget-area ' . esc_attr( $class ) . '"';
	}
}

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function wen_biz_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'wen_biz_content_width', 920 );
}
add_action( 'after_setup_theme', 'wen_biz_content_width', 0 );

if ( ! function_exists( 'wen_biz_template_redirect' ) ) :
	/**
	 * Set the content width in pixels, based on the theme's design and stylesheet for different value other than the default one
	 *
	 * @global int $content_width
	 */
	function wen_biz_template_redirect() {
		$layout = wen_biz_get_theme_layout();

		if ( 'no-sidebar-full-width' === $layout ) {
			$GLOBALS['content_width'] = 1510;
		}

		if ( is_singular() ) {
			$GLOBALS['content_width'] = 680;
		}
	}
endif;
add_action( 'template_redirect', 'wen_biz_template_redirect' );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function wen_biz_widgets_init() {
	$args = array(
		'before_widget' => '<section id="%1$s" class="widget %2$s"> <div class="widget-wrap">',
		'after_widget'  => '</div></section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	);

	register_sidebar( array(
		'name'        => esc_html__( 'Sidebar', 'wen-biz' ),
		'id'          => 'sidebar-1',
		'description' => esc_html__( 'Add widgets here.', 'wen-biz' ),
		) + $args
	);

	register_sidebar( array(
		'name'        => esc_html__( 'Footer 1', 'wen-biz' ),
		'id'          => 'sidebar-2',
		'description' => esc_html__( 'Add widgets here to appear in your footer.', 'wen-biz' ),
		) + $args
	);

	register_sidebar( array(
		'name'        => esc_html__( 'Footer 2', 'wen-biz' ),
		'id'          => 'sidebar-3',
		'description' => esc_html__( 'Add widgets here to appear in your footer.', 'wen-biz' ),
		) + $args
	);

	register_sidebar( array(
		'name'        => esc_html__( 'Footer 3', 'wen-biz' ),
		'id'          => 'sidebar-4',
		'description' => esc_html__( 'Add widgets here to appear in your footer.', 'wen-biz' ),
		) + $args
	);
}
add_action( 'widgets_init', 'wen_biz_widgets_init' );

if ( ! function_exists( 'wen_biz_fonts_url' ) ) :
	/**
	 * Register Google fonts for WEN Biz
	 *
	 * Create your own wen_biz_fonts_url() function to override in a child theme.
	 *
	 * @since 1.0.0
	 *
	 * @return string Google fonts URL for the theme.
	 */
	function wen_biz_fonts_url() {
		$fonts_url = '';
		/* Translators: If there are characters in your language that are not
	* supported by Open Sans, translate this to 'off'. Do not translate
	* into your own language.
	*/
	$open_sans = _x( 'on', 'Open Sans: on or off', 'wen-biz' );

	/* Translators: If there are characters in your language that are not
	* supported by Playfair Display, translate this to 'off'. Do not translate
	* into your own language.
	*/
	$titillium_web = _x( 'on', 'Titillium Web: on or off', 'wen-biz' );

	if ( 'off' !== $open_sans || 'off' !== $titillium_web ) {
		$font_families = array();

		if ( 'off' !== $open_sans ) {
		$font_families[] = 'Open Sans:300,400,500,600,700,900,400italic,700italic';
		}

		if ( 'off' !== $titillium_web ) {
		$font_families[] = 'Titillium Web:300,400,500,600,700,900,400italic,700italic';
		}

		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( 'latin,latin-ext' ),
		);

		$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
	}

	return esc_url_raw( $fonts_url );
	}
endif;

/**
 * Handles JavaScript detection.
 *
 * Adds a `js` class to the root `<html>` element when JavaScript is detected.
 *
 * @since 1.0.0
 */
function wen_biz_javascript_detection() {
	echo "<script>(function(html){html.className = html.className.replace(/\bno-js\b/,'js')})(document.documentElement);</script>\n";
}
add_action( 'wp_head', 'wen_biz_javascript_detection', 0 );

/**
 * Enqueue scripts and styles.
 */
function wen_biz_scripts() {
	$min  = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

	// Add custom fonts, used in the main stylesheet.
	wp_enqueue_style( 'wen-biz-fonts', wen_biz_fonts_url(), array(), null );

	// Theme stylesheet.
	wp_enqueue_style( 'wen-biz-style', get_stylesheet_uri(), null, date( 'Ymd-Gis', filemtime( get_template_directory() . '/style.css' ) ) );

	// Theme block stylesheet.
	wp_enqueue_style( 'wen-biz-block-style', get_theme_file_uri( '/css/blocks.css' ), array( 'wen-biz-style' ), '1.0' );

	// Load the html5 shiv.
	wp_enqueue_script( 'wen-biz-html5',  get_template_directory_uri() . '/js/html5' . $min . '.js', null, '3.7.3' );

	wp_script_add_data( 'wen-biz-html5', 'conditional', 'lt IE 9' );

	wp_enqueue_script( 'wen-biz-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix' . $min . '.js', array(), '201800703', true );


	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	$deps[] = 'jquery';

	//Slider Scripts
	$enable_slider      = wen_biz_check_section( get_theme_mod( 'wen_biz_slider_option', 'disabled' ) );
	$enable_testimonial_slider      = wen_biz_check_section( get_theme_mod( 'wen_biz_testimonial_option', 'disabled' ) );

	if ( $enable_slider || $enable_testimonial_slider ) {
		// Enqueue owl carousel css. Must load CSS before JS.
		wp_enqueue_style( 'owl-carousel-core', get_theme_file_uri( 'css/owl-carousel/owl.carousel' . $min . '.css' ), null, '2.3.4' );
		wp_enqueue_style( 'owl-carousel-default', get_theme_file_uri( 'css/owl-carousel/owl.theme.default' . $min . '.css' ), null, '2.3.4' );
		// Enqueue script
		wp_enqueue_script( 'owl-carousel', get_theme_file_uri( 'js/owl.carousel' . $min . '.js' ) , array( 'jquery' ), '2.3.4', true );

		$deps[] = 'owl-carousel';
	}

	$deps[] = 'jquery-masonry';

	wp_enqueue_script( 'wen-biz-script', get_template_directory_uri() . '/js/functions' . $min . '.js', $deps, '201800703', true );

	wp_localize_script( 'wen-biz-script', 'wenBizOptions', array(
		'screenReaderText' => array(
			'expand'   => esc_html__( 'expand child menu', 'wen-biz' ),
			'collapse' => esc_html__( 'collapse child menu', 'wen-biz' ),
			'icon'     => wen_biz_get_svg( array(
					'icon'     => 'angle-down',
					'fallback' => true,
				)
			),
		),
		'iconNavPrev'     => wen_biz_get_svg( array(
				'icon'     => 'angle-left',
				'fallback' => true,
			)
		),
		'iconNavNext'     => wen_biz_get_svg( array(
				'icon'     => 'angle-right',
				'fallback' => true,
			)
		),
		'rtl' => is_rtl(),
		'dropdownIcon'     => wen_biz_get_svg( array( 'icon' => 'angle-down', 'fallback' => true ) ),
	) );

	// Remove Media CSS, we have ouw own CSS for this.
	wp_deregister_style('wp-mediaelement');
}
add_action( 'wp_enqueue_scripts', 'wen_biz_scripts' );

/**
 * Enqueue editor styles for Gutenberg
 */
function wen_biz_block_editor_styles() {
	// Bail on customizer preview page.
	if ( is_customize_preview() ) {
		return;
	}

	// Block styles.
	wp_enqueue_style( 'wen-biz-block-editor-style', get_theme_file_uri( 'css/editor-blocks.css' ) );

	// Add custom fonts.
	wp_enqueue_style( 'wen-biz-fonts', wen_biz_fonts_url(), array(), null );
}
add_action( 'enqueue_block_editor_assets', 'wen_biz_block_editor_styles' );

if ( ! function_exists( 'wen_biz_excerpt_length' ) ) :
	/**
	 * Sets the post excerpt length to n words.
	 *
	 * function tied to the excerpt_length filter hook.
	 * @uses filter excerpt_length
	 *
	 * @since 1.0.0
	 */
	function wen_biz_excerpt_length( $length ) {
		if ( is_admin() ) {
			return $length;
		}

		// Getting data from Customizer Options
		$length	= get_theme_mod( 'wen_biz_excerpt_length', 25 );

		return absint( $length );
	}
endif; //wen_biz_excerpt_length
add_filter( 'excerpt_length', 'wen_biz_excerpt_length', 999 );

if ( ! function_exists( 'wen_biz_excerpt_more' ) ) :
	/**
	 * Replaces "[...]" (appended to automatically generated excerpts) with ... and a option from customizer
	 *
	 * @return string option from customizer prepended with an ellipsis.
	 */
	function wen_biz_excerpt_more( $more ) {
		if ( is_admin() ) {
			return $more;
		}

		$more_tag_text = get_theme_mod( 'wen_biz_excerpt_more_text',  esc_html__( 'Continue reading', 'wen-biz' ) );

		$link = sprintf( '<span class="more-button"><a href="%1$s" class="more-link">%2$s</a></a>',
			esc_url( get_permalink() ),
			/* translators: %s: Name of current post */
			wp_kses_data( $more_tag_text ) . '<span class="screen-reader-text">' . get_the_title( get_the_ID() ) . '</span>'
		);

		return $link;
	}
endif;
add_filter( 'excerpt_more', 'wen_biz_excerpt_more' );

if ( ! function_exists( 'wen_biz_custom_excerpt' ) ) :
	/**
	 * Adds Continue reading link to more tag excerpts.
	 *
	 * function tied to the get_the_excerpt filter hook.
	 *
	 * @since 1.0.0
	 */
	function wen_biz_custom_excerpt( $output ) {
		if ( has_excerpt() && ! is_attachment() ) {
			$more_tag_text = get_theme_mod( 'wen_biz_excerpt_more_text', esc_html__( 'Continue reading', 'wen-biz' ) );

			$link = sprintf( '<span class="more-button"><a href="%1$s" class="more-link">%2$s</a></a>',
				esc_url( get_permalink() ),
				/* translators: %s: Name of current post */
				wp_kses_data( $more_tag_text ). '<span class="screen-reader-text">' . get_the_title( get_the_ID() ) . '</span>'
			);

			$link = ' &hellip; ' . $link;

			$output .= $link;
		}

		return $output;
	}
endif; //wen_biz_custom_excerpt
add_filter( 'get_the_excerpt', 'wen_biz_custom_excerpt' );

if ( ! function_exists( 'wen_biz_more_link' ) ) :
	/**
	 * Replacing Continue reading link to the_content more.
	 *
	 * function tied to the the_content_more_link filter hook.
	 *
	 * @since 1.0.0
	 */
	function wen_biz_more_link( $more_link, $more_link_text ) {
		$more_tag_text = get_theme_mod( 'wen_biz_excerpt_more_text', esc_html__( 'Continue reading', 'wen-biz' ) );

		return ' &hellip; ' . str_replace( $more_link_text, wp_kses_data( $more_tag_text ), $more_link );
	}
endif; //wen_biz_more_link
add_filter( 'the_content_more_link', 'wen_biz_more_link', 10, 2 );

/**
 * Register the required plugins for this theme.
 *
 * In this example, we register five plugins:
 * - one included with the TGMPA library
 * - two from an external source, one from an arbitrary source, one from a GitHub repository
 * - two from the .org repo, where one demonstrates the use of the `is_callable` argument
 *
 * The variables passed to the `tgmpa()` function should be:
 * - an array of plugin arrays;
 * - optionally a configuration array.
 * If you are not changing anything in the configuration array, you can remove the array and remove the
 * variable from the function call: `tgmpa( $plugins );`.
 * In that case, the TGMPA default settings will be used.
 *
 * This function is hooked into `tgmpa_register`, which is fired on the WP `init` action on priority 10.
 */
function wen_biz_register_required_plugins() {
	/*
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$plugins = array(
		array(
			'name' => esc_html__( 'Contact Form 7', 'wen-biz' ),
			'slug' => 'contact-form-7',
		),
		array(
			'name' => esc_html__( 'WEN Featured Image', 'wen-biz' ),
			'slug' => 'wen-featured-image',
		),
		array(
			'name' => esc_html__( 'Catch Themes Demo Import', 'wen-biz' ),
			'slug' => 'catch-themes-demo-import',
		),
	);

	/*
	 * Array of configuration settings. Amend each line as needed.
	 *
	 * TGMPA will start providing localized text strings soon. If you already have translations of our standard
	 * strings available, please help us make TGMPA even better by giving us access to these translations or by
	 * sending in a pull-request with .po file(s) with the translations.
	 *
	 * Only uncomment the strings in the config array if you want to customize the strings.
	 */
	$config = array(
		'id'           => 'wen-biz',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
	);

	tgmpa( $plugins, $config );
}
add_action( 'tgmpa_register', 'wen_biz_register_required_plugins' );

/**
 * SVG icons functions and filters
 */
require get_parent_theme_file_path( '/inc/icon-functions.php' );

/**
 * Implement the Custom Header feature
 */
require get_parent_theme_file_path( '/inc/custom-header.php' );

/**
 * Custom template tags for this theme
 */
require get_parent_theme_file_path( '/inc/template-tags.php' );

/**
 * Functions which enhance the theme by hooking into WordPress
 */
require get_parent_theme_file_path( '/inc/template-functions.php' );

/**
 * Customizer additions
 */
require get_parent_theme_file_path( '/inc/customizer/customizer.php' );

/**
 * Color Scheme additions
 */
require get_parent_theme_file_path( '/inc/color-scheme.php' );

/**
 * Load Jetpack compatibility file
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_parent_theme_file_path( '/inc/jetpack.php' );
}

/**
 * Load TGMPA
 */
require get_parent_theme_file_path( '/inc/class-tgm-plugin-activation.php' );

/**
 * Load Theme About Page
 */
require get_parent_theme_file_path( '/inc/admin/admin.php' );


function my_attachments_search( $query ) {
 if ( !is_search() ) 
    return $query; 		
 
  $post_types = $query->get( 'post_type' );
  if ( ! $post_types || 'post' == $post_types )
    $post_types = array( 'post', 'attachment' );
 
  if ( is_array( $post_types ) ) 
    $post_types[] = 'attachment';
 
  $query->set( 'post_type', $post_types );
  return $query;
}
// hook our function to the filter
add_filter( 'pre_get_posts', 'my_attachments_search' );
