<?php
/**
 * Hero Content Options
 *
 * @package Wen_Biz
 */

/**
 * Add hero content options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_biz_hero_content_options( $wp_customize ) {
	$wp_customize->add_section( 'wen_biz_hero_content_options', array(
			'title' => esc_html__( 'Hero Content', 'wen-biz' ),
			'panel' => 'wen_biz_theme_options',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_hero_content_visibility',
			'default'           => 'disabled',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'choices'           => wen_biz_section_visibility_options(),
			'label'             => esc_html__( 'Enable on', 'wen-biz' ),
			'section'           => 'wen_biz_hero_content_options',
			'type'              => 'select',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_hero_content_tagline',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_biz_is_hero_content_active',
			'label'             => esc_html__( 'Section Tagline', 'wen-biz' ),
			'section'           => 'wen_biz_hero_content_options',
			'type'              => 'text',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_hero_content',
			'default'           => '0',
			'sanitize_callback' => 'wen_biz_sanitize_post',
			'active_callback'   => 'wen_biz_is_hero_content_active',
			'label'             => esc_html__( 'Page', 'wen-biz' ),
			'section'           => 'wen_biz_hero_content_options',
			'type'              => 'dropdown-pages',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_hero_content_block_one_title',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_biz_is_hero_custom_content_full_content_active',
			'label'             => esc_html__( 'Block One Title', 'wen-biz' ),
			'section'           => 'wen_biz_hero_content_options',
			'type'              => 'text',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_hero_content_block_one_image',
			'sanitize_callback' => 'wen_biz_sanitize_image',
			'custom_control'    => 'WP_Customize_Image_Control',
			'active_callback'   => 'wen_biz_is_hero_custom_content_full_content_active',
			'label'             => esc_html__( 'Block One Icon', 'wen-biz' ),
			'section'           => 'wen_biz_hero_content_options',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_hero_content_block_one_content',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_biz_is_hero_custom_content_full_content_active',
			'label'             => esc_html__( 'Block One Content', 'wen-biz' ),
			'section'           => 'wen_biz_hero_content_options',
			'type'              => 'textarea',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_hero_content_block_two_title',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_biz_is_hero_custom_content_full_content_active',
			'label'             => esc_html__( 'Block Two Title', 'wen-biz' ),
			'section'           => 'wen_biz_hero_content_options',
			'type'              => 'text',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_hero_content_block_two_image',
			'sanitize_callback' => 'wen_biz_sanitize_image',
			'custom_control'    => 'WP_Customize_Image_Control',
			'active_callback'   => 'wen_biz_is_hero_custom_content_full_content_active',
			'label'             => esc_html__( 'Block Two Icon', 'wen-biz' ),
			'section'           => 'wen_biz_hero_content_options',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_hero_content_block_two_content',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'wen_biz_is_hero_custom_content_full_content_active',
			'label'             => esc_html__( 'Block Two Content', 'wen-biz' ),
			'section'           => 'wen_biz_hero_content_options',
			'type'              => 'textarea',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_hero_content_show',
			'default'           => 'excerpt',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'active_callback'   => 'wen_biz_is_hero_content_active',
			'choices'           => wen_biz_content_show(),
			'label'             => esc_html__( 'Display Content', 'wen-biz' ),
			'section'           => 'wen_biz_hero_content_options',
			'type'              => 'select',
		)
	);
}
add_action( 'customize_register', 'wen_biz_hero_content_options' );

/** Active Callback Functions **/
if ( ! function_exists( 'wen_biz_is_hero_content_active' ) ) :
	/**
	* Return true if hero content is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_hero_content_active( $control ) {
		$enable = $control->manager->get_setting( 'wen_biz_hero_content_visibility' )->value();

		return wen_biz_check_section( $enable );
	}
endif;

if ( ! function_exists( 'wen_biz_is_hero_custom_content_full_content_active' ) ) :
	/**
	* Return true if hero custom content is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_hero_custom_content_full_content_active( $control ) {
		$content_show = $control->manager->get_setting( 'wen_biz_hero_content_show' )->value();

		return ( wen_biz_is_hero_content_active( $control ) && 'full-content' === $content_show );
	}
endif;
