<?php
/**
 * Add Portfolio Settings in Customizer
 *
 * @package Wen_Biz
 */

/**
 * Add portfolio options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_biz_portfolio_options( $wp_customize ) {
	$wp_customize->add_section( 'wen_biz_portfolio', array(
			'panel'    => 'wen_biz_theme_options',
			'title'    => esc_html__( 'Portfolio', 'wen-biz' ),
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_portfolio_option',
			'default'           => 'disabled',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'choices'           => wen_biz_section_visibility_options(),
			'label'             => esc_html__( 'Enable on', 'wen-biz' ),
			'section'           => 'wen_biz_portfolio',
			'type'              => 'select',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_portfolio_tagline',
			'sanitize_callback' => 'wp_kses_post',
			'label'             => esc_html__( 'Section Tagline', 'wen-biz' ),
			'active_callback'   => 'wen_biz_is_portfolio_active',
			'section'           => 'wen_biz_portfolio',
			'type'              => 'text',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_portfolio_title',
			'default'           => esc_html__( 'My Works', 'wen-biz' ),
			'sanitize_callback' => 'wp_kses_post',
			'label'             => esc_html__( 'Section Title', 'wen-biz' ),
			'active_callback'   => 'wen_biz_is_portfolio_active',
			'section'           => 'wen_biz_portfolio',
			'type'              => 'text',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_portfolio_number',
			'default'           => 6,
			'sanitize_callback' => 'wen_biz_sanitize_number_range',
			'active_callback'   => 'wen_biz_is_portfolio_active',
			'label'             => esc_html__( 'Number of items to show', 'wen-biz' ),
			'section'           => 'wen_biz_portfolio',
			'type'              => 'number',
			'input_attrs'       => array(
				'style'             => 'width: 100px;',
				'min'               => 0,
			),
		)
	);

	$number = get_theme_mod( 'wen_biz_portfolio_number', 6 );

	for ( $i = 1; $i <= $number ; $i++ ) {
		wen_biz_register_option( $wp_customize, array(
				'name'              => 'wen_biz_portfolio_page_' . $i,
				'sanitize_callback' => 'wen_biz_sanitize_post',
				'active_callback'   => 'wen_biz_is_portfolio_active',
				'label'             => esc_html__( 'Page', 'wen-biz' ) . ' ' . $i ,
				'section'           => 'wen_biz_portfolio',
				'type'              => 'dropdown-pages',
			)
		);
	} // End for().
}
add_action( 'customize_register', 'wen_biz_portfolio_options' );

/**
 * Active Callback Functions
 */
if ( ! function_exists( 'wen_biz_is_portfolio_active' ) ) :
	/**
	* Return true if portfolio is active
	*
	* @since 1.0.0
	*/
	function wen_biz_is_portfolio_active( $control ) {
		$enable = $control->manager->get_setting( 'wen_biz_portfolio_option' )->value();

		//return true only if previwed page on customizer matches the type of content option selected
		return wen_biz_check_section( $enable );
	}
endif;