<?php
/**
 * Add Testimonial Settings in Customizer
 *
 * @package Wen_Biz
*/

/**
 * Add testimonial options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_biz_testimonial_options( $wp_customize ) {
   $wp_customize->add_section( 'wen_biz_testimonials', array(
            'panel'    => 'wen_biz_theme_options',
            'title'    => esc_html__( 'Testimonials', 'wen-biz' ),
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_testimonial_option',
            'default'           => 'disabled',
            'sanitize_callback' => 'wen_biz_sanitize_select',
            'choices'           => wen_biz_section_visibility_options(),
            'label'             => esc_html__( 'Enable on', 'wen-biz' ),
            'section'           => 'wen_biz_testimonials',
            'type'              => 'select',
            'priority'          => 1,
        )
    );    

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_testimonial_transition_timeout',
            'default'           => 4,
            'sanitize_callback' => 'wen_biz_sanitize_number_range',
            'active_callback'   => 'wen_biz_is_testimonial_active',
            'input_attrs'       => array(
                'style'       => 'width: 100px;',
                'min'         => 0,
            ),
            'label'             => esc_html__( 'Transition timeout', 'wen-biz' ),
            'section'           => 'wen_biz_testimonials',
            'type'              => 'number',
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_testimonial_tagline',
            'sanitize_callback' => 'wp_kses_post',
            'label'             => esc_html__( 'Section Tagline', 'wen-biz' ),
            'active_callback'   => 'wen_biz_is_testimonial_active',
            'section'           => 'wen_biz_testimonials',
            'type'              => 'text',
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_testimonial_title',
            'default'           => esc_html__( 'Testimonials', 'wen-biz' ),
            'sanitize_callback' => 'wp_kses_post',
            'label'             => esc_html__( 'Section Title', 'wen-biz' ),
            'active_callback'   => 'wen_biz_is_testimonial_active',
            'section'           => 'wen_biz_testimonials',
            'type'              => 'text',
        )
    );

    wen_biz_register_option( $wp_customize, array(
            'name'              => 'wen_biz_testimonial_number',
            'default'           => '5',
            'sanitize_callback' => 'wen_biz_sanitize_number_range',
            'active_callback'   => 'wen_biz_is_testimonial_active',
            'label'             => esc_html__( 'Number of items', 'wen-biz' ),
            'section'           => 'wen_biz_testimonials',
            'type'              => 'number',
            'input_attrs'       => array(
                'style'             => 'width: 100px;',
                'min'               => 0,
            ),
        )
    );

    $number = get_theme_mod( 'wen_biz_testimonial_number', 5 );

    for ( $i = 1; $i <= $number ; $i++ ) {
        wen_biz_register_option( $wp_customize, array(
                'name'              => 'wen_biz_testimonial_page_' . $i,
                'sanitize_callback' => 'wen_biz_sanitize_post',
                'active_callback'   => 'wen_biz_is_testimonial_active',
                'label'             => esc_html__( 'Page', 'wen-biz' ) . ' ' . $i ,
                'section'           => 'wen_biz_testimonials',
                'type'              => 'dropdown-pages',
            )
        );

        wen_biz_register_option( $wp_customize, array(
                'name'              => 'wen_biz_testimonial_position_' . $i,
                'sanitize_callback' => 'sanitize_text_field',
                'active_callback'   => 'wen_biz_is_testimonial_active',
                'label'             => esc_html__( 'Position', 'wen-biz' ),
                'section'           => 'wen_biz_testimonials',
                'type'              => 'text',
            )
        );
    } // End for().
}
add_action( 'customize_register', 'wen_biz_testimonial_options' );

/**
 * Active Callback Functions
 */
if ( ! function_exists( 'wen_biz_is_testimonial_active' ) ) :
    /**
    * Return true if testimonial is active
    *
    * @since 1.0.0
    */
    function wen_biz_is_testimonial_active( $control ) {
        $enable = $control->manager->get_setting( 'wen_biz_testimonial_option' )->value();

        //return true only if previwed page on customizer matches the type of content option selected
        return wen_biz_check_section( $enable );
    }
endif;

if ( ! function_exists( 'wen_biz_is_post_testimonial_active' ) ) :
    /**
    * Return true if page content is active
    *
    * @since 1.0.0
    */
    function wen_biz_is_post_testimonial_active( $control ) {
        $type = $control->manager->get_setting( 'wen_biz_testimonial_type' )->value();

        //return true only if previwed page on customizer matches the type of option selected
        return ( wen_biz_is_testimonial_active( $control ) && 'post' === $type );
    }
endif;

if ( ! function_exists( 'wen_biz_is_jetpack_testimonial_active' ) ) :
    /**
    * Return true if jetpack testimonial is active
    *
    * @since 1.0.0
    */
    function wen_biz_is_jetpack_testimonial_active( $control ) {
        $type = $control->manager->get_setting( 'wen_biz_testimonial_type' )->value();

        //return true only if previwed page on customizer matches the type of option selected
        return ( wen_biz_is_testimonial_active( $control ) && 'jetpack-testimonial' === $type );
    }
endif;

if ( ! function_exists( 'wen_biz_is_page_testimonial_active' ) ) :
    /**
    * Return true if page content is active
    *
    * @since 1.0.0
    */
    function wen_biz_is_page_testimonial_active( $control ) {
        $type = $control->manager->get_setting( 'wen_biz_testimonial_type' )->value();

        //return true only if previwed page on customizer matches the type of option selected
        return ( wen_biz_is_testimonial_active( $control ) && 'page' === $type );
    }
endif;

if ( ! function_exists( 'wen_biz_is_category_testimonial_active' ) ) :
    /**
    * Return true if page content is active
    *
    * @since 1.0.0
    */
    function wen_biz_is_category_testimonial_active( $control ) {
        $type = $control->manager->get_setting( 'wen_biz_testimonial_type' )->value();

        //return true only if previwed page on customizer matches the type of option selected
        return ( wen_biz_is_testimonial_active( $control ) && 'category' === $type );
    }
endif;

if ( ! function_exists( 'wen_biz_is_post_page_category_cpt_testimonial_active' ) ) :
    /**
    * Return true if custom option is not active
    *
    * @since 1.0.0
    */
    function wen_biz_is_post_page_category_cpt_testimonial_active( $control ) {
        $type = $control->manager->get_setting( 'wen_biz_testimonial_type' )->value();

        //return true only if previwed page on customizer matches the type of option selected
        return ( wen_biz_is_testimonial_active( $control ) && 'custom' !== $type );
    }
endif;

if ( ! function_exists( 'wen_biz_is_cpt_testimonial_inactive' ) ) :
    /**
    * Return true if cpt option is not active
    *
    * @since 1.0.0
    */
    function wen_biz_is_cpt_testimonial_inactive( $control ) {
        $type = $control->manager->get_setting( 'wen_biz_testimonial_type' )->value();

        //return true only if previwed page on customizer matches the type of option selected
        return ( wen_biz_is_testimonial_active( $control ) && 'jetpack-testimonial' !== $type );
    }
endif;

if ( ! function_exists( 'wen_biz_is_image_testimonial_active' ) ) :
    /**
    * Return true if page content is active
    *
    * @since 1.0.0
    */
    function wen_biz_is_image_testimonial_active( $control ) {
        $type = $control->manager->get_setting( 'wen_biz_testimonial_type' )->value();

        //return true only if previwed page on customizer matches the type of option selected
        return ( wen_biz_is_testimonial_active( $control ) && 'custom' === $type );
    }
endif;
