<?php
/**
 * Theme Options
 *
 * @package Wen_Biz
 */

/**
 * Add theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function wen_biz_theme_options( $wp_customize ) {
	$wp_customize->add_panel( 'wen_biz_theme_options', array(
		'title'    => esc_html__( 'Theme Options', 'wen-biz' ),
		'priority' => 130,
	) );

	// Footer Options.
	$wp_customize->add_section( 'wen_biz_footer_options', array(
		'title'       => esc_html__( 'Footer Options', 'wen-biz' ),
		'description' => esc_html__( 'You can either add html or plain text or custom shortcodes, which will be automatically inserted into your theme. Some shorcodes: [the-year], [site-link] and [privacy-policy-link] for current year, site link and privacy policy link respectively.', 'wen-biz' ),
		'panel'       => 'wen_biz_theme_options',
	) );

	$theme_data = wp_get_theme();

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_footer_copyright_text',
			'default'           => sprintf( _x( 'Copyright &copy; %1$s %2$s %3$s', '1: Year, 2: Site Title with home URL, 3: Privacy Policy Link', 'wen-biz' ), '[the-year]', '[site-link]', '[privacy-policy-link]' ) . '<span class="sep"> | </span>',
			'sanitize_callback' => 'wp_kses_post',
			'label'             => esc_html__( 'Copyright Text', 'wen-biz' ),
			'section'           => 'wen_biz_footer_options',
			'type'              => 'textarea',
		)
	);

	// Layout Options
	$wp_customize->add_section( 'wen_biz_layout_options', array(
		'title' => esc_html__( 'Layout Options', 'wen-biz' ),
		'panel' => 'wen_biz_theme_options',
		)
	);

	/* Default Layout */
	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_default_layout',
			'default'           => 'right-sidebar',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'label'             => esc_html__( 'Default Layout', 'wen-biz' ),
			'section'           => 'wen_biz_layout_options',
			'type'              => 'select',
			'choices'           => array(
				'right-sidebar'         => esc_html__( 'Right Sidebar ( Content, Primary Sidebar )', 'wen-biz' ),
				'no-sidebar'            => esc_html__( 'No Sidebar', 'wen-biz' ),
			),
		)
	);

	/* Homepage/Archive Layout */
	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_homepage_archive_layout',
			'default'           => 'right-sidebar',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'label'             => esc_html__( 'Homepage/Archive Layout', 'wen-biz' ),
			'section'           => 'wen_biz_layout_options',
			'type'              => 'select',
			'choices'           => array(
				'right-sidebar'         => esc_html__( 'Right Sidebar ( Content, Primary Sidebar )', 'wen-biz' ),
				
				'no-sidebar'            => esc_html__( 'No Sidebar', 'wen-biz' ),
			),
		)
	);

	/* Single Page/Post Image */
	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_single_layout',
			'default'           => 'disabled',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'label'             => esc_html__( 'Single Page/Post Image', 'wen-biz' ),
			'section'           => 'wen_biz_layout_options',
			'type'              => 'select',
			'choices'           => array(
				'disabled'        => esc_html__( 'Disabled', 'wen-biz' ),
				'post-thumbnail'  => esc_html__( 'Post Thumbnail', 'wen-biz' ),
		)
	) );

	// Excerpt Options.
	$wp_customize->add_section( 'wen_biz_excerpt_options', array(
		'panel'     => 'wen_biz_theme_options',
		'title'     => esc_html__( 'Excerpt Options', 'wen-biz' ),
	) );

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_excerpt_length',
			'default'           => '25',
			'sanitize_callback' => 'absint',
			'input_attrs' => array(
				'min'   => 10,
				'max'   => 200,
				'step'  => 5,
				'style' => 'width: 80px;',
			),
			'label'    => esc_html__( 'Excerpt Length (words)', 'wen-biz' ),
			'section'  => 'wen_biz_excerpt_options',
			'type'     => 'number',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_excerpt_more_text',
			'default'           => esc_html__( 'Continue reading', 'wen-biz' ),
			'sanitize_callback' => 'sanitize_text_field',
			'label'             => esc_html__( 'Read More Text', 'wen-biz' ),
			'section'           => 'wen_biz_excerpt_options',
			'type'              => 'text',
		)
	);

	// Search Options.
	$wp_customize->add_section( 'wen_biz_search_options', array(
		'panel'     => 'wen_biz_theme_options',
		'title'     => esc_html__( 'Search Options', 'wen-biz' ),
	) );

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_search_text',
			'default'           => esc_html__( 'Search a keyword', 'wen-biz' ),
			'sanitize_callback' => 'sanitize_text_field',
			'label'             => esc_html__( 'Search Text', 'wen-biz' ),
			'section'           => 'wen_biz_search_options',
			'type'              => 'text',
		)
	);

	// Homepage / Frontpage Options.
	$wp_customize->add_section( 'wen_biz_homepage_options', array(
		'description' => esc_html__( 'Only posts that belong to the categories selected here will be displayed on the front page', 'wen-biz' ),
		'panel'       => 'wen_biz_theme_options',
		'title'       => esc_html__( 'Homepage / Frontpage Options', 'wen-biz' ),
	) );
	
	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_recent_posts_title',
			'sanitize_callback' => 'sanitize_text_field',
			'default'           => esc_html__( 'From Our Blog', 'wen-biz' ),
			'label'             => esc_html__( 'Recent Posts Title', 'wen-biz' ),
			'section'           => 'wen_biz_homepage_options',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_static_page_heading',
			'sanitize_callback' => 'sanitize_text_field',
			'active_callback'	=> 'wen_biz_is_static_page_enabled',
			'default'           => esc_html__( 'Archives', 'wen-biz' ),
			'label'             => esc_html__( 'Posts Page Header Text', 'wen-biz' ),
			'section'           => 'wen_biz_homepage_options',
		)
	);

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_front_page_category',
			'sanitize_callback' => 'wen_biz_sanitize_category_list',
			'custom_control'    => 'Wen_Biz_Multi_Cat',
			'label'             => esc_html__( 'Categories', 'wen-biz' ),
			'section'           => 'wen_biz_homepage_options',
			'type'              => 'dropdown-categories',
		)
	);

	//Menu Options
	$wp_customize->add_section( 'wen_biz_menu_options', array(
		'description' => esc_html__( 'Extra Menu Options specific to this theme', 'wen-biz' ),
		'title'       => esc_html__( 'Menu Options', 'wen-biz' ),
		'panel'       => 'wen_biz_theme_options',
	) );

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_primary_search_enable',
			'default'			=> 1,
			'sanitize_callback' => 'wen_biz_sanitize_checkbox',
			'label'             => esc_html__( 'Search in Primary Menu', 'wen-biz' ),
			'section'           => 'wen_biz_menu_options',
			'custom_control'    => 'Wen_Biz_Toggle_Control',
		)
	);
	//Menu Options End

	// Pagination Options.
	$pagination_type = get_theme_mod( 'wen_biz_pagination_type', 'default' );

	$nav_desc = '';

	/**
	* Check if navigation type is Jetpack Infinite Scroll and if it is enabled
	*/
	$nav_desc = sprintf(
		wp_kses(
			__( 'For infinite scrolling, use %1$sJetpack%2$s with Infinite Scroll module Enabled.', 'wen-biz' ),
			array(
				'a' => array(
					'href' => array(),
					'target' => array(),
				),
				'br'=> array()
			)
		),
		'<a target="_blank" href="https://wordpress.org/plugins/jetpack/">',
		'</a>'
	);

	$wp_customize->add_section( 'wen_biz_pagination_options', array(
		'description'     => $nav_desc,
		'panel'           => 'wen_biz_theme_options',
		'title'           => esc_html__( 'Pagination Options', 'wen-biz' ),
		'active_callback' => 'wen_biz_scroll_plugins_inactive'
	) );

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_pagination_type',
			'default'           => 'default',
			'sanitize_callback' => 'wen_biz_sanitize_select',
			'choices'           => wen_biz_get_pagination_types(),
			'label'             => esc_html__( 'Pagination type', 'wen-biz' ),
			'section'           => 'wen_biz_pagination_options',
			'type'              => 'select',
		)
	);

	/* Scrollup Options */
	$wp_customize->add_section( 'wen_biz_scrollup', array(
		'panel'    => 'wen_biz_theme_options',
		'title'    => esc_html__( 'Scrollup Options', 'wen-biz' ),
	) );

	wen_biz_register_option( $wp_customize, array(
			'name'              => 'wen_biz_disable_scrollup',
			'default'			=> 1,
			'sanitize_callback' => 'wen_biz_sanitize_checkbox',
			'label'             => esc_html__( 'Scroll Up', 'wen-biz' ),
			'section'           => 'wen_biz_scrollup',
			'custom_control'    => 'Wen_Biz_Toggle_Control',
		)
	);
}
add_action( 'customize_register', 'wen_biz_theme_options' );

/** Active Callback Functions */
if ( ! function_exists( 'wen_biz_scroll_plugins_inactive' ) ) :
	/**
	* Return true if infinite scroll functionality exists
	*
	* @since 1.0.0
	*/
	function wen_biz_scroll_plugins_inactive( $control ) {
		if ( ( class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'infinite-scroll' ) ) || class_exists( 'Catch_Infinite_Scroll' ) ) {
			// Support infinite scroll plugins.
			return false;
		}

		return true;
	}
endif;

if ( ! function_exists( 'wen_biz_is_static_page_enabled' ) ) :
	/**
	* Return true if A Static Page is enabled
	*
	* @since 1.0.0
	*/
	function wen_biz_is_static_page_enabled( $control ) {
		$enable = $control->manager->get_setting( 'show_on_front' )->value();
		if ( 'page' === $enable ) {
			return true;
		}
		return false;
	}
endif;

if ( ! function_exists( 'wen_biz_scroll_plugins_inactive' ) ) :
	/**
	* Return true if infinite scroll functionality exists
	*
	* @since 1.0.0
	*/
	function wen_biz_scroll_plugins_inactive( $control ) {
		if ( ( class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'infinite-scroll' ) ) || class_exists( 'Catch_Infinite_Scroll' ) ) {
			// Support infinite scroll plugins.
			return false;
		}

		return true;
	}
endif;
