<?php
/**
 * The template used for displaying hero content
 *
 * @package Wen_Biz
 */

if ( $wen_biz_id = get_theme_mod( 'wen_biz_hero_content' ) ) {
	$wen_biz_args['page_id'] = absint( $wen_biz_id );
}

// If $wen_biz_args is empty return false
if ( empty( $wen_biz_args ) ) {
	return;
}

$wen_biz_classes[] = 'hero-section';
$wen_biz_classes[] = 'section';
$wen_biz_classes[] = 'content-align-right';
$wen_biz_classes[] = 'text-align-left';

// Create a new WP_Query using the argument previously created
$hero_query = new WP_Query( $wen_biz_args );
if ( $hero_query->have_posts() ) :
	while ( $hero_query->have_posts() ) :
		$hero_query->the_post();
		?>
		<div id="hero-section" class="<?php echo esc_attr( implode( ' ', $wen_biz_classes ) ); ?>">
			<div class="wrapper">
				<div class="section-content-wrapper hero-content-wrapper">
					<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
						<div class="hentry-inner">
							<?php $post_thumbnail = wen_biz_post_thumbnail( 'wen-biz-hero', 'html', false ); // wen_biz_post_thumbnail( $image_size, $wen_biz_type = 'html', $echo = true, $no_thumb = false ).

						if ( has_post_thumbnail() ) :
							echo $post_thumbnail;
							?>
							<div class="entry-container">
						<?php else : ?>
							<div class="entry-container full-width">
						<?php endif; ?>
							<?php
							$wen_biz_tagline = get_theme_mod( 'wen_biz_hero_content_tagline' ); ?>
								<header class="entry-header">
									<?php if ( $wen_biz_tagline ) : ?>
										<div class="section-tagline">
											<?php echo wp_kses_post( $wen_biz_tagline ); ?>
										</div><!-- .section-tagline -->
									<?php endif; ?>
									<h2 class="entry-title">
										<?php the_title(); ?>
									</h2>
								</header><!-- .entry-header -->

							<?php
							$show_content = get_theme_mod( 'wen_biz_hero_content_show', 'excerpt' );

							if ( 'full-content' === $show_content ) {
								?>
								<div class="entry-content">
									<?php the_content(); ?>
									<?php 
									$block_one_title = get_theme_mod( 'wen_biz_hero_content_block_one_title' );
									$block_one_image = get_theme_mod( 'wen_biz_hero_content_block_one_image' );
									$block_one_content = get_theme_mod( 'wen_biz_hero_content_block_one_content' );
									$block_two_title = get_theme_mod( 'wen_biz_hero_content_block_two_title' );
									$block_two_image = get_theme_mod( 'wen_biz_hero_content_block_two_image' );
									$block_two_content = get_theme_mod( 'wen_biz_hero_content_block_two_content' ); ?>
									<?php if ( $block_one_title || $block_one_image || $block_one_content ) : ?>
										<div class="block-one">
											<?php if ( $block_one_image ) : ?>
												<img src="<?php echo esc_url( $block_one_image ); ?>">
											<?php endif; ?>
											<div class="block-content-wrapper">	
												<?php if ( $block_one_title ) : ?>
													<span class="block-one-title">
														<?php echo wp_kses_post( $block_one_title ); ?>
													</span>
												<?php endif; ?>	
												<?php echo wpautop( wp_kses_post( $block_one_content ) ); ?>
											</div>
										</div>
									<?php endif; ?>
									<?php if ( $block_two_title || $block_two_image || $block_two_content ) : ?>
										<div class="block-two">
											<?php if ( $block_two_image ) : ?>
												<img src="<?php echo esc_url( $block_two_image ); ?>">
											<?php endif; ?>	
											<div class="block-content-wrapper">
												<?php if ( $block_two_title ) : ?>
													<span class="block-two-title">
														<?php echo wp_kses_post( $block_two_title ); ?>
													</span>
												<?php endif; ?>		
												<?php echo wpautop( wp_kses_post( $block_two_content ) ); ?>
											</div>
										</div>
									<?php endif; ?>
								</div><!-- .entry-content -->
								<?php
							} elseif ( 'excerpt' === $show_content ) {
								?>
								<div class="entry-summary">
									<?php the_excerpt();  ?>
								</div><!-- .entry-summary -->
								<?php
							}
							?>

							<?php if ( get_edit_post_link() ) : ?>
								<footer class="entry-footer">
									<div class="entry-meta">
										<?php
											edit_post_link(
												sprintf(
													/* translators: %s: Name of current post */
													esc_html__( 'Edit %s', 'wen-biz' ),
													the_title( '<span class="screen-reader-text">"', '"</span>', false )
												),
												'<span class="edit-link">',
												'</span>'
											);
										?>
									</div>	<!-- .entry-meta -->
								</footer><!-- .entry-footer -->
							<?php endif; ?>
						</div><!-- .hentry-inner -->
					</article>
				</div><!-- .section-content-wrapper -->
			</div><!-- .wrapper -->
		</div><!-- .section -->
	<?php
	endwhile;

	wp_reset_postdata();
endif;
